pub fn parse_spread_order_event(
msg: &OKXSpreadOrder,
client_order_id: ClientOrderId,
account_id: AccountId,
trader_id: TraderId,
strategy_id: StrategyId,
instrument: &InstrumentAny,
previous_filled_qty: Option<Quantity>,
previous_state: Option<&OrderStateSnapshot>,
ts_init: UnixNanos,
) -> Result<ParsedOrderEvent>Expand description
Parses an OKX spread order message into a specific order event.
Errors
Returns an error if parsing order identifiers or numeric fields fails.