pub fn parse_spread_order_msg(
msg: &OKXSpreadOrder,
account_id: AccountId,
instruments: &AHashMap<Ustr, InstrumentAny>,
filled_qty_cache: &AHashMap<Ustr, Quantity>,
ts_init: UnixNanos,
) -> Result<ExecutionReport>Expand description
Parses a single OKX spread order message into an ExecutionReport.
Errors
Returns an error if the instrument cannot be found or if parsing the underlying order payload fails.