pub fn parse_algo_order_status_report(
msg: &OKXAlgoOrderMsg,
instrument: &InstrumentAny,
account_id: AccountId,
ts_init: UnixNanos,
) -> Result<OrderStatusReport>Expand description
Parses an OKX algo order message into a Nautilus order status report.
Errors
Returns an error if any order identifiers or numeric fields cannot be parsed.